@@ -196,6 +196,13 @@ def get_identifier_description(data, column_name, data_type, data_subtype, other
     data = list(data)
     unquie_pct = len(set(data))/len(data)
 
+    lenghts = [len(str(x)) for x in data]
+    mean_len = np.mean(lenghts)
+    max_len = np.max(lenghts)
+
+    spaces = [len(str(x).split(' ')) - 1 for x in data]
+    mean_spaces = np.mean(spaces)
+
     # Detect auto incrementing index
     if data_subtype == DATA_SUBTYPES.INT:
         if get_pct_auto_increment(data) > 0.98 and unquie_pct > 0.99:
@@ -265,4 +272,8 @@ def get_identifier_description(data, column_name, data_type, data_subtype, other
             else:
                 return 'Unknown identifier'
 
+    # Everything is unique and it's too short to be rich text
+    if data_type in (DATA_TYPES.CATEGORICAL, DATA_TYPES.TEXT) and unquie_pct > 0.999 and mean_spaces < 1:
+        return 'Unknown identifier'
+
     return None
